@@ -1,5 +1,5 @@
 /*  Rational - Rational number class with overflow detection
-    Copyright (C) 2012-2015 Antonio Diaz Diaz.
+    Copyright (C) 2012-2016 Antonio Diaz Diaz.
 
     This program is free software: you have unlimited permission to
     copy, distribute and modify it.
@@ -31,7 +31,7 @@ namespace {
 
 const char * const Program_name = "Rational";
 const char * const program_name = "rational";
-const char * const program_year = "2015";
+const char * const program_year = "2016";
 const char * invocation_name = 0;
 
 
@@ -69,9 +69,8 @@ void show_error( const char * const msg, const int errcode = 0,
   if( msg && msg[0] )
     {
     std::fprintf( stderr, "%s: %s", program_name, msg );
-    if( errcode > 0 )
-      std::fprintf( stderr, ": %s.", std::strerror( errcode ) );
-    std::fprintf( stderr, "\n" );
+    if( errcode > 0 ) std::fprintf( stderr, ": %s", std::strerror( errcode ) );
+    std::fputc( '\n', stderr );
     }
   if( help )
     std::fprintf( stderr, "Try '%s --help' for more information.\n",
@@ -94,7 +93,7 @@ void approximate_pi()
   int n = 3, d = 1, digit = 0;
 
   std::printf( "target == %s\n", target.c_str() );
-  std::printf( "correct\ndecimals                  value\n" );
+  std::fputs( "correct\ndecimals                  value\n", stdout );
   while( n < INT_MAX )
     {
     if( n / d != 3 ) { if( n / d < 3 ) ++n; else ++d; continue; }
@@ -129,7 +128,7 @@ void approximate_sqrt( const int itarget )
   int n = 1, d = 1;
 
   std::printf( "target == sqrt( %d )\n", itarget );
-  std::printf( "        error               value^2          value\n" );
+  std::fputs( "        error               value^2          value\n", stdout );
   while( n < INT_MAX )
     {
     const Rational value( n, d );
@@ -161,12 +160,12 @@ int run_tests( const int level, const bool verbose )
   {
   const Rational r( 1, 0 );
   if( !r.error() )
-    { std::fprintf( stderr, "error: Rational( 1, 0 ) not rejected\n" );
+    { std::fputs( "error: Rational( 1, 0 ) not rejected.\n", stderr );
       retval = 1; }
   if( r == 0 || r == 1 || r == INT_MAX || r == -INT_MAX ||
       !(r != 0) || !(r != 1) || !(r != INT_MAX) || !(r != -INT_MAX) ||
       r > -INT_MAX || r >= -INT_MAX || r < INT_MAX || r <= INT_MAX )
-    { std::fprintf( stderr, "error: bad relational result on error\n" );
+    { std::fputs( "error: bad relational result on error.\n", stderr );
       retval = 1; }
   }
 
@@ -174,23 +173,23 @@ int run_tests( const int level, const bool verbose )
   {
   const Rational r0( INT_MAX, 1 );
   if( r0 != INT_MAX )
-    { std::fprintf( stderr, "error: Rational( INT_MAX, 1 ) not accepted\n" );
+    { std::fputs( "error: Rational( INT_MAX, 1 ) not accepted.\n", stderr );
       retval = 1; }
   Rational r( INT_MIN, 1 );
   if( !r.error() )
-    { std::fprintf( stderr, "error: Rational( INT_MIN, 1 ) not rejected\n" );
+    { std::fputs( "error: Rational( INT_MIN, 1 ) not rejected.\n", stderr );
       retval = 1; }
   r.assign( INT_MAX, 1 );
   if( r != INT_MAX || r != r0 )
-    { std::fprintf( stderr, "error: r.assign( INT_MAX, 1 ) not accepted\n" );
+    { std::fputs( "error: r.assign( INT_MAX, 1 ) not accepted.\n", stderr );
       retval = 1; }
   r.assign( INT_MIN, 1 );
   if( !r.error() )
-    { std::fprintf( stderr, "error: r.assign( INT_MIN, 1 ) not rejected\n" );
+    { std::fputs( "error: r.assign( INT_MIN, 1 ) not rejected.\n", stderr );
       retval = 1; }
   r.assign( -INT_MAX, 1 );
   if( r != -INT_MAX || r != -r0 || -r != r0 )
-    { std::fprintf( stderr, "error: r.assign( -INT_MAX, 1 ) not accepted\n" );
+    { std::fputs( "error: r.assign( -INT_MAX, 1 ) not accepted.\n", stderr );
       retval = 1; }
   }
 
@@ -198,24 +197,24 @@ int run_tests( const int level, const bool verbose )
   {
   const Rational r0( 1, INT_MAX );
   if( r0.numerator() != 1 || r0.denominator() != INT_MAX )
-    { std::fprintf( stderr, "error: Rational( 1, INT_MAX ) not accepted\n" );
+    { std::fputs( "error: Rational( 1, INT_MAX ) not accepted.\n", stderr );
       retval = 1; }
   Rational r( 1, INT_MIN );
   if( !r.error() )
-    { std::fprintf( stderr, "error: Rational( 1, INT_MIN ) not rejected\n" );
+    { std::fputs( "error: Rational( 1, INT_MIN ) not rejected.\n", stderr );
       retval = 1; }
   r.assign( 1, INT_MAX );
   if( r.numerator() != 1 || r.denominator() != INT_MAX || r != r0 )
-    { std::fprintf( stderr, "error: r.assign( 1, INT_MAX ) not accepted\n" );
+    { std::fputs( "error: r.assign( 1, INT_MAX ) not accepted.\n", stderr );
       retval = 1; }
   r.assign( 1, INT_MIN );
   if( !r.error() )
-    { std::fprintf( stderr, "error: r.assign( 1, INT_MIN ) not rejected\n" );
+    { std::fputs( "error: r.assign( 1, INT_MIN ) not rejected.\n", stderr );
       retval = 1; }
   r.assign( 1, -INT_MAX );
   if( r.numerator() != -1 || r.denominator() != INT_MAX ||
       r != -r0 || -r != r0 )
-    { std::fprintf( stderr, "error: r.assign( 1, -INT_MAX ) not accepted\n" );
+    { std::fputs( "error: r.assign( 1, -INT_MAX ) not accepted.\n", stderr );
       retval = 1; }
   }
 
@@ -223,23 +222,23 @@ int run_tests( const int level, const bool verbose )
   {
   const Rational r0( INT_MAX, INT_MAX );
   if( r0 != 1 )
-    { std::fprintf( stderr, "error: Rational( INT_MAX, INT_MAX ) not accepted\n" );
+    { std::fputs( "error: Rational( INT_MAX, INT_MAX ) not accepted.\n", stderr );
       retval = 1; }
   Rational r( INT_MIN, INT_MIN );
   if( !r.error() )
-    { std::fprintf( stderr, "error: Rational( INT_MIN, INT_MIN ) not rejected\n" );
+    { std::fputs( "error: Rational( INT_MIN, INT_MIN ) not rejected.\n", stderr );
       retval = 1; }
   r.assign( INT_MAX, INT_MAX );
   if( r != 1 || r != r0 )
-    { std::fprintf( stderr, "error: r.assign( INT_MAX, INT_MAX ) not accepted\n" );
+    { std::fputs( "error: r.assign( INT_MAX, INT_MAX ) not accepted.\n", stderr );
       retval = 1; }
   r.assign( INT_MIN, INT_MIN );
   if( !r.error() )
-    { std::fprintf( stderr, "error: r.assign( INT_MIN, INT_MIN ) not rejected\n" );
+    { std::fputs( "error: r.assign( INT_MIN, INT_MIN ) not rejected.\n", stderr );
       retval = 1; }
   r.assign( INT_MAX, -INT_MAX );
   if( r != -1 || r != -r0 || -r != r0 )
-    { std::fprintf( stderr, "error: r.assign( INT_MAX, -INT_MAX ) not accepted\n" );
+    { std::fputs( "error: r.assign( INT_MAX, -INT_MAX ) not accepted.\n", stderr );
       retval = 1; }
   }
 
@@ -247,30 +246,30 @@ int run_tests( const int level, const bool verbose )
   {
   const Rational r0( INT_MAX );
   if( r0 != INT_MAX )
-    { std::fprintf( stderr, "error: Rational( INT_MAX ) not accepted\n" );
+    { std::fputs( "error: Rational( INT_MAX ) not accepted.\n", stderr );
       retval = 1; }
   Rational r( INT_MIN );
   if( !r.error() )
-    { std::fprintf( stderr, "error: Rational( INT_MIN ) not rejected\n" );
+    { std::fputs( "error: Rational( INT_MIN ) not rejected.\n", stderr );
       retval = 1; }
   r = INT_MAX;
   if( r != INT_MAX || r != r0 )
-    { std::fprintf( stderr, "error: ( r = INT_MAX ) not accepted\n" );
+    { std::fputs( "error: ( r = INT_MAX ) not accepted.\n", stderr );
       retval = 1; }
   r = INT_MIN;
   if( !r.error() )
-    { std::fprintf( stderr, "error: ( r = INT_MIN ) not rejected\n" );
+    { std::fputs( "error: ( r = INT_MIN ) not rejected.\n", stderr );
       retval = 1; }
   r = -INT_MAX;
   if( r != -INT_MAX || r != -r0 || -r != r0 )
-    { std::fprintf( stderr, "error: ( r = -INT_MAX ) not accepted\n" );
+    { std::fputs( "error: ( r = -INT_MAX ) not accepted.\n", stderr );
       retval = 1; }
   r = 0;
   if( r != 0 || r != r0 - r0 || r != -r )
-    { std::fprintf( stderr, "error: ( r = 0 ) not accepted\n" ); retval = 1; }
+    { std::fputs( "error: ( r = 0 ) not accepted.\n", stderr ); retval = 1; }
   r = r.inverse();
   if( !r.error() )
-    { std::fprintf( stderr, "error: inverse( 0 ) not rejected\n" );
+    { std::fputs( "error: inverse( 0 ) not rejected.\n", stderr );
       retval = 1; }
   }
 
@@ -279,7 +278,7 @@ int run_tests( const int level, const bool verbose )
   const Rational r1( 0, 1 );
   const Rational r2( 0 );
   if( r1 != r2 || r1 != -r2 || r1 + r2 != 0 || r1 - r2 != 0 || r1 * r2 != 0 )
-    { std::fprintf( stderr, "error: ( 0, 1 ) != ( 0 )\n" ); retval = 1; }
+    { std::fputs( "error: ( 0, 1 ) != ( 0 )\n", stderr ); retval = 1; }
   }
 
   // intermediate overflow test
@@ -289,7 +288,7 @@ int run_tests( const int level, const bool verbose )
   if( r1 != -r2 || -r1 != r2 || r1 + r2 != 0 ||
       r1 + r1 !=  INT_MAX || 2 * r1 !=  INT_MAX ||
       r2 + r2 != -INT_MAX || 2 * r2 != -INT_MAX )
-    { std::fprintf( stderr, "error: INT_MAX/2 + INT_MAX/2 != INT_MAX\n" );
+    { std::fputs( "error: INT_MAX/2 + INT_MAX/2 != INT_MAX\n", stderr );
       retval = 1; }
   }
 
@@ -444,7 +443,7 @@ int run_tests( const int level, const bool verbose )
     { std::fprintf( stderr, "error: sum is not zero ( sum == %s )\n",
                     sum.to_decimal( 1, -100 ).c_str() ); retval = 1; }
   if( !zero )
-    { std::fprintf( stderr, "error: zero not reached in sum loop\n" );
+    { std::fputs( "error: zero not reached in sum loop.\n", stderr );
       retval = 1; }
   }
 
@@ -466,7 +465,7 @@ int run_tests( const int level, const bool verbose )
                       r1.to_decimal( 1, -100 ).c_str() ); retval = 1; }
     }
   if( !one )
-    { std::fprintf( stderr, "error: one not reached in mul loop\n" );
+    { std::fputs( "error: one not reached in mul loop.\n", stderr );
       retval = 1; }
   }
 
@@ -482,7 +481,7 @@ int run_tests( const int level, const bool verbose )
                     r.to_fraction().c_str() ); retval = 1; }
   }
 
-  if( verbose && retval == 0 ) std::fprintf( stderr, "Test passed.\n" );
+  if( verbose && retval == 0 ) std::fputs( "Test passed.\n", stderr );
   return retval;
   }
 
